@@ -8,14 +8,16 @@ import shutil
 import subprocess
 import time
 from typing import Generator
-from typing import Tuple
-from typing import Type
 
 from cryptography.hazmat.primitives.asymmetric.ec import EllipticCurve
 from cryptography.hazmat.primitives.asymmetric.ec import SECP256R1
 from cryptography.hazmat.primitives.asymmetric.ec import SECP384R1
 from cryptography.hazmat.primitives.asymmetric.ec import SECP521R1
+from cryptography.hazmat.primitives.asymmetric import ec
+from cryptography import x509
+from cryptography.x509 import ExtensionNotFound
 from cryptography.x509 import NameOID
+from cryptography.x509 import TLSFeatureType
 import pytest
 
 from certbot_integration_tests.certbot_tests.assertions import assert_cert_count_for_lineage
@@ -96,17 +98,14 @@ def test_prepare_plugins(context: IntegrationTestsContext) -> None:
 
 def test_http_01(context: IntegrationTestsContext) -> None:
     """Test the HTTP-01 challenge using standalone plugin."""
-    # We start a server listening on the port for the
-    # TLS-SNI challenge to prevent regressions in #3601.
-    with misc.create_http_server(context.tls_alpn_01_port):
-        certname = context.get_domain('le2')
-        context.certbot([
-            '--domains', certname, '--preferred-challenges', 'http-01', 'run',
-            '--cert-name', certname,
-            '--pre-hook', misc.echo('wtf_pre', context.hook_probe),
-            '--post-hook', misc.echo('wtf_post', context.hook_probe),
-            '--deploy-hook', misc.echo('deploy', context.hook_probe),
-        ])
+    certname = context.get_domain('le2')
+    context.certbot([
+        '--domains', certname, '--preferred-challenges', 'http-01', 'run',
+        '--cert-name', certname,
+        '--pre-hook', misc.echo('wtf_pre', context.hook_probe),
+        '--post-hook', misc.echo('wtf_post', context.hook_probe),
+        '--deploy-hook', misc.echo('deploy', context.hook_probe),
+    ])
 
     assert_hook_execution(context.hook_probe, 'deploy')
     assert_saved_renew_hook(context.config_dir, certname)
@@ -573,7 +572,7 @@ def test_reuse_key_allow_subset_of_names(context: IntegrationTestsContext) -> No
 
 def test_new_key(context: IntegrationTestsContext) -> None:
     """Tests --new-key and its interactions with --reuse-key"""
-    def private_key(generation: int) -> Tuple[str, str]:
+    def private_key(generation: int) -> tuple[str, str]:
         pk_path = join(context.config_dir, f'archive/{certname}/privkey{generation}.pem')
         with open(pk_path, 'r') as file:
             return file.read(), pk_path
@@ -642,7 +641,10 @@ def test_ecdsa(context: IntegrationTestsContext) -> None:
     ])
 
     certificate = misc.read_certificate(cert_path)
-    assert 'ASN1 OID: secp384r1' in certificate
+    # Check that the certificate uses SECP384R1 curve
+    public_key = certificate.public_key()
+    assert isinstance(public_key, ec.EllipticCurvePublicKey)
+    assert isinstance(public_key.curve, ec.SECP384R1)
 
 
 def test_default_key_type(context: IntegrationTestsContext) -> None:
@@ -673,7 +675,7 @@ def test_default_rsa_size(context: IntegrationTestsContext) -> None:
     ('secp521r1', SECP521R1)]
 )
 def test_ecdsa_curves(context: IntegrationTestsContext, curve: str,
-                      curve_cls: Type[EllipticCurve]) -> None:
+                      curve_cls: type[EllipticCurve]) -> None:
     """Test issuance for each supported ECDSA curve"""
     domain = context.get_domain('curve')
     context.certbot([
@@ -741,7 +743,12 @@ def test_ocsp_must_staple(context: IntegrationTestsContext) -> None:
 
     certificate = misc.read_certificate(join(context.config_dir,
                                              'live/{0}/cert.pem').format(certname))
-    assert 'status_request' in certificate or '1.3.6.1.5.5.7.1.24' in certificate
+
+    try:
+        tls_feature_ext = certificate.extensions.get_extension_for_class(x509.TLSFeature)
+        assert TLSFeatureType.status_request in list(tls_feature_ext.value)
+    except ExtensionNotFound:
+        assert False, "OCSP Must-Staple requires TLS Feature extension"
 
 
 def test_revoke_simple(context: IntegrationTestsContext) -> None:
@@ -809,7 +816,7 @@ def test_revoke_and_unregister(context: IntegrationTestsContext) -> None:
     ('secp521r1', SECP521R1)]
 )
 def test_revoke_ecdsa_cert_key(
-    context: IntegrationTestsContext, curve: str, curve_cls: Type[EllipticCurve]) -> None:
+    context: IntegrationTestsContext, curve: str, curve_cls: type[EllipticCurve]) -> None:
     """Test revoking a certificate """
     cert: str = context.get_domain('curve')
     context.certbot([
@@ -834,7 +841,7 @@ def test_revoke_ecdsa_cert_key(
     ('secp521r1', SECP521R1)]
 )
 def test_revoke_ecdsa_cert_key_delete(
-    context: IntegrationTestsContext, curve: str, curve_cls: Type[EllipticCurve]) -> None:
+    context: IntegrationTestsContext, curve: str, curve_cls: type[EllipticCurve]) -> None:
     """Test revoke and deletion for each supported curve type"""
     cert: str = context.get_domain('curve')
     context.certbot([
@@ -1016,8 +1023,9 @@ def test_preferred_chain(context: IntegrationTestsContext) -> None:
                 '--preferred-chain', requested, '--force-renewal']
         context.certbot(args)
 
-        dumped = misc.read_certificate(cert_path)
-        assert f'Issuer: CN={expected}'in dumped, \
+        certificate = misc.read_certificate(cert_path)
+        issuer_cn = certificate.issuer.get_attributes_for_oid(NameOID.COMMON_NAME)[0].value
+        assert expected == issuer_cn, \
                f'Expected chain issuer to be {expected} when preferring {requested}'
 
         with open(conf_path, 'r') as f:
